.. AUTO-GENERATED FILE -- DO NOT EDIT!

devices.basedevice
==================

Module: :mod:`devices.basedevice`
---------------------------------
Inheritance diagram for ``zmq.devices.basedevice``:

.. inheritance-diagram:: zmq.devices.basedevice 
   :parts: 3

.. automodule:: zmq.devices.basedevice

.. currentmodule:: zmq.devices.basedevice

Classes
-------

:class:`BackgroundDevice`
~~~~~~~~~~~~~~~~~~~~~~~~~


.. autoclass:: BackgroundDevice
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:


:class:`Device`
~~~~~~~~~~~~~~~


.. autoclass:: Device
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:


:class:`ProcessDevice`
~~~~~~~~~~~~~~~~~~~~~~


.. autoclass:: ProcessDevice
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:


:class:`ThreadDevice`
~~~~~~~~~~~~~~~~~~~~~


.. autoclass:: ThreadDevice
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

